.. _examples:

========
Examples
========

.. toctree::
   :maxdepth: 1

   note_about_examples

-----------
Quick Start
-----------

- :ref:`example_quick_start`
- :ref:`example_tracking_quick_start`

-------------
Preprocessing
-------------

Gradients & Spheres
~~~~~~~~~~~~~~~~~~~

- :ref:`example_gradients_spheres`

Brain Extraction
~~~~~~~~~~~~~~~~

- :ref:`example_brain_extraction_dwi`

SNR estimation
~~~~~~~~~~~~~~

- :ref:`example_snr_in_cc`

Reslice
~~~~~~~

- :ref:`example_reslice_datasets`

--------------
Reconstruction
--------------

Constrained Spherical Deconvolution
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

- :ref:`example_reconst_csd`

Simple Harmonic Oscillator based Reconstruction and Estimation
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

- :ref:`example_reconst_shore`
- :ref:`example_reconst_shore_metrics`


Diffusion Tensor Imaging
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

- :ref:`example_reconst_dti`
- :ref:`example_restore_dti`


Q-Ball Constant Solid Angle
~~~~~~~~~~~~~~~~~~~~~~~~~~~

- :ref:`example_reconst_csa`


Diffusion Spectrum Imaging
~~~~~~~~~~~~~~~~~~~~~~~~~~

- :ref:`example_reconst_dsi`
- :ref:`example_reconst_dsi_metrics`


Generalized Q-Sampling Imaging
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

- :ref:`example_reconst_gqi`

DSI with Deconvolution
~~~~~~~~~~~~~~~~~~~~~~

- :ref:`example_reconst_dsid`

--------------
Fiber tracking
--------------

- :ref:`example_tracking_eudx_tensor`
- :ref:`example_tracking_eudx_odf`
- :ref:`example_probabilistic_tracking_odfs`

-------------------
Streamline analysis
-------------------

- :ref:`example_streamline_tools`
- :ref:`example_streamline_length`

------------
Segmentation
------------

Streamline Clustering
~~~~~~~~~~~~~~~~~~~~~

- :ref:`example_segment_quickbundles`

Brain Segmentation
~~~~~~~~~~~~~~~~~~
- :ref:`example_brain_extraction_dwi`

-----------
Simulations
-----------

- :ref:`example_simulate_multi_tensor`
- :ref:`example_reconst_dsid`

---------------
Multiprocessing
---------------

- :ref:`example_reconst_csd_parallel`
- :ref:`example_reconst_csa_parallel`

------------
File Formats
------------

- :ref:`example_streamline_formats`


.. In order to build the examples, you'll need (on Debian)
    sudo apt-get install python-tables python-matplotib python-vtk
